@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-29'; # DATE
+our $DATE = '2021-10-05'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.039'; # VERSION
+our $VERSION = '0.040'; # VERSION
 
 sub meta {
     +{
@@ -27,7 +27,13 @@ sub coerce {
     $res->{expr_match} = "!ref($dt)";
     $res->{expr_coerce} = join(
         "",
-        "do { my \$tmp = $dt; \$tmp = \$1 if \$tmp =~ m!\\A(\\w+(?:/\\w+)*)\.pm\\z!; \$tmp =~ s!::?|/|\\.|-!::!g; \$tmp }",
+        "do { my \$tmp = $dt;",
+        "  my \$argssuffix = ''; \$argssuffix = \$1 if \$tmp =~ s/(=.*)\\z//;",                                  # extract args suffix (=arg1,arg2) first
+        "  my \$versuffix = ''; \$versuffix = \$1 if \$tmp =~ s/(\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*)\\z//;", # extract version suffix part first
+        "  \$tmp = \$1 if \$tmp =~ m!\\A(\\w+(?:/\\w+)*)\.pm\\z!;",
+        "  \$tmp =~ s!::?|/|\\.|-!::!g;",
+        "  \$tmp . \$versuffix . \$argssuffix",
+        "}",
     );
 
     $res;
@@ -48,7 +54,7 @@ Data::Sah::Coerce::perl::To_str::From_str::normalize_perl_modname_or_prefix
 
 =head1 VERSION
 
-This document describes version 0.039 of Data::Sah::Coerce::perl::To_str::From_str::normalize_perl_modname_or_prefix (from Perl distribution Sah-Schemas-Perl), released on 2021-09-29.
+This document describes version 0.040 of Data::Sah::Coerce::perl::To_str::From_str::normalize_perl_modname_or_prefix (from Perl distribution Sah-Schemas-Perl), released on 2021-10-05.
 
 =head1 DESCRIPTION
 
